#
# spec file for package python-pyshark
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyshark
Version:        0.6
Release:        1.4
Summary:        A Python wrapper for tshark output parsing
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/KimiNewt/pyshark
#Git-Clone:     https://github.com/KimiNewt/pyshark.git
Source:         https://github.com/KimiNewt/pyshark/archive/v%{version}.tar.gz
BuildRequires:  %{python_module appdirs}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module py}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module termcolor}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  wireshark
Requires:       python-appdirs
Requires:       python-lxml
Requires:       python-py
Requires:       python-termcolor
Requires:       wireshark
BuildArch:      noarch
%python_subpackages

%description
Python wrapper for tshark, allowing python packet parsing using
wireshark dissectors.

%prep
%setup -q -n pyshark-%{version}/src

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test "inmem_capture" needs to be fixed upstream, do not run it for now
rm -f ../tests/capture/test_inmem_capture.py ../tests/capture/test_live_capture.py
%pytest ../tests

%files %{python_files}
%license ../LICENSE.txt
%doc ../README.md
%{python_sitelib}/pyshark
%{python_sitelib}/pyshark-%{version}.dist-info

%changelog
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6:
  * Dropped support for Python 3.5/3.6
  * Fix elastic mapping for new Wireshark 4
  * Accepting rpcap:// as a valid interface name
  * Add args and kwargs to RemoteCapture __init__
  * Replace py dependency with termcolor.
  * Unicode support added to correct issue617
  * Make packet layer names case-insensitive for backward
    compatibility with v0.4.6
- update to 0.5.3:
  * EK Bugfixes version
  * Fix LiveRingCapture params.
- update to 0.5.2:
  * Add some params for LiveRingCapture.
  * EK Layer now supports "payload"-type fields by casting to
    bytes.
  * EK Layer has new "get_field_as_list" function to assist with
    getting fields that may appear once or more
  * Fixed issues with printing boolean fields in EK layer.
  * Fixed verification of capture interface on LiveCapture.
- update to 0.5:
  * New EK parsing mode, allowing faster and easier use than the
    regular JSON mode which will likely be eventually deprecated.
  * Support typing in EK mode.
  * Checking file permissions in FileCapture
  * Show tshark error in crash exception
  * Verify capture settings before starting capture
  * Fix path when user provides `tshark_path` using
    `LiveCapture`.
  * Fix some tshark_path problems.
  * Fix Windows eventloop-related issues
* Sat Jun 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.6
  Changes
  * Added type hints for major classes.
  * Edited docs to comply with PEP8.
  Fixes
  * Python 3.10 and Python 3.9 compatibility.
  * Fixed crashed related to LiveRingCapture.
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.3
  * Upstream does not provide a changelog
* Fri Sep 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.2.11
  * Added option to use ujson in tshark 2.6+
  * Bugfix when parsing multiple InMemCapture packets
  * Removed logbook, using builtin logging instead
  * Enabled setting debug in Capture init
  * Added lazy feature in JSON object to convert showname field
    keys to normal keys
  * Bugfix for InMem json capture
  * Fixed tests
- Test "inmem_capture" is broken and needs to be addressed upstream.
  - > disable this test for now
* Tue Aug 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not run tests twice
* Fri Aug  2 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.4.2.3
